@@ -4,7 +4,7 @@ use v5.14;
 use warnings;
 use utf8;
 
-our $VERSION = "2.2104";
+our $VERSION = "2.22";
 
 use Data::Dumper;
 $Data::Dumper::Sortkeys = 1;
@@ -120,20 +120,23 @@ our %TABSTYLE = (
     pairmap {
 	( $a =~ s/_/-/gr => ref $b ? $b : [ $b, $b ] );
     }
-    symbol => [ "\N{SYMBOL FOR HORIZONTAL TABULATION}",			    # ␉
-		"\N{SYMBOL FOR SPACE}" ],				    # ␠
-    shade  => [ "\N{MEDIUM SHADE}",					    # ▒
-		"\N{LIGHT SHADE}" ],					    # ░
-    block  => [ "\N{LOWER ONE QUARTER BLOCK}",				    # ▂
-		"\N{LOWER ONE EIGHTH BLOCK}" ],				    # ▁
-    bar    => [ "\N{BOX DRAWINGS HEAVY RIGHT}",				    # ╺
-		"\N{BOX DRAWINGS LIGHT HORIZONTAL}" ],			    # ─
-    dash   => [ "\N{BOX DRAWINGS HEAVY RIGHT}",				    # ╺
-		"\N{BOX DRAWINGS LIGHT DOUBLE DASH HORIZONTAL}" ],	    # ╌
+    symbol   => [ "\N{SYMBOL FOR HORIZONTAL TABULATION}",		    # ␉
+		  "\N{SYMBOL FOR SPACE}" ],				    # ␠
+    shade    => [ "\N{MEDIUM SHADE}",					    # ▒
+		  "\N{LIGHT SHADE}" ],					    # ░
+    block    => [ "\N{LOWER ONE QUARTER BLOCK}",			    # ▂
+		  "\N{LOWER ONE EIGHTH BLOCK}" ],			    # ▁
+    pin      => [ "\N{BOX DRAWINGS HEAVY RIGHT}",			    # ╺
+		  "\N{BOX DRAWINGS LIGHT HORIZONTAL}" ],		    # ─
+    dash     => [ "\N{BOX DRAWINGS HEAVY RIGHT}",			    # ╺
+		  "\N{BOX DRAWINGS LIGHT DOUBLE DASH HORIZONTAL}" ],	    # ╌
+    triangle => [ "\N{BLACK RIGHT-POINTING SMALL TRIANGLE}",		    # ▸
+		  "\N{WHITE RIGHT-POINTING SMALL TRIANGLE}" ],		    # ▹
 
     dot          => '.',
     space        => ' ',
     emspace      => "\N{EM SPACE}",					    #  
+    blank        => "\N{OPEN BOX}",					    # ␣
     middle_dot   => "\N{MIDDLE DOT}",					    # ·
     arrow        => "\N{RIGHTWARDS ARROW}",				    # →
     double_arrow => "\N{RIGHTWARDS DOUBLE ARROW}",			    # ⇒
@@ -150,6 +153,10 @@ our %TABSTYLE = (
 
     );
 
+for my $alias ([ bar => 'pin']) {
+    $TABSTYLE{$alias->[0]} = $TABSTYLE{$alias->[1]};
+}
+
 my @default = (
     text      => '',
     width     => undef,
@@ -454,6 +461,7 @@ sub fold {
     if ($opt->{padding} and $room > 0) {
 	my $padding = $opt->{padchar} x $room;
 	if (@bg_stack) {
+	    $padding .= $opt->{padchar} x $opt->{runin} if $opt->do_runin;
 	    $padding = join '', @bg_stack, $padding, SGR_RESET;
 	}
 	$folded .= $padding;
@@ -554,7 +562,7 @@ Text::ANSI::Fold - Text folding library supporting ANSI terminal sequence and As
 
 =head1 VERSION
 
-Version 2.2104
+Version 2.22
 
 =head1 SYNOPSIS
 
@@ -764,6 +772,10 @@ B<chops> interface.
 If the value is reference to subroutine, its result is used as a
 prefix string.
 
+The B<fold> function does not complain if the result of adding a
+prefix string is longer than the original text.  The caller must be
+very careful because of the possibility of an infinite loop.
+
 =item B<ambiguous> => C<narrow> or C<wide>
 
 Tells how to treat Unicode East Asian ambiguous characters.  Default
@@ -832,16 +844,18 @@ C<symbols>'s tabhead and C<space>'s tabspace.
 
 Currently these names are available.
 
-    symbol => [ "\N{SYMBOL FOR HORIZONTAL TABULATION}",
-                "\N{SYMBOL FOR SPACE}" ],
-    shade  => [ "\N{MEDIUM SHADE}",
-                "\N{LIGHT SHADE}" ],
-    block  => [ "\N{LOWER ONE QUARTER BLOCK}",
-                "\N{LOWER ONE EIGHTH BLOCK}" ],
-    bar    => [ "\N{BOX DRAWINGS HEAVY RIGHT}",
-                "\N{BOX DRAWINGS LIGHT HORIZONTAL}" ],
-    dash   => [ "\N{BOX DRAWINGS HEAVY RIGHT}",
-                "\N{BOX DRAWINGS LIGHT DOUBLE DASH HORIZONTAL}" ],
+    symbol   => [ "\N{SYMBOL FOR HORIZONTAL TABULATION}",
+                  "\N{SYMBOL FOR SPACE}" ],
+    shade    => [ "\N{MEDIUM SHADE}",
+                  "\N{LIGHT SHADE}" ],
+    block    => [ "\N{LOWER ONE QUARTER BLOCK}",
+                  "\N{LOWER ONE EIGHTH BLOCK}" ],
+    pin      => [ "\N{BOX DRAWINGS HEAVY RIGHT}",
+                  "\N{BOX DRAWINGS LIGHT HORIZONTAL}" ],
+    dash     => [ "\N{BOX DRAWINGS HEAVY RIGHT}",
+                  "\N{BOX DRAWINGS LIGHT DOUBLE DASH HORIZONTAL}" ],
+    triangle => [ "\N{BLACK RIGHT-POINTING SMALL TRIANGLE}",
+		  "\N{WHITE RIGHT-POINTING SMALL TRIANGLE}" ],
 
 Below are styles providing same character for both tabhead and
 tabspace.
@@ -849,6 +863,7 @@ tabspace.
     dot          => '.',
     space        => ' ',
     emspace      => "\N{EM SPACE}",
+    blank        => "\N{OPEN BOX}",
     middle-dot   => "\N{MIDDLE DOT}",
     arrow        => "\N{RIGHTWARDS ARROW}",
     double-arrow => "\N{RIGHTWARDS DOUBLE ARROW}",
@@ -954,7 +969,7 @@ Kazumasa Utashiro
 
 =head1 LICENSE
 
-Copyright ©︎ 2018-2023 Kazumasa Utashiro.
+Copyright ©︎ 2018-2024 Kazumasa Utashiro.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
